//
//  File: ShapeView.C
//
//  ET++ Tutorial   Lernabschnitt:  5     Command & Menu
//

#include "ET++.h"

#include "ShapeView.h"
#include "ShapeCommand.h"

extern int cMAXINKS;

//---- ShapeView ---------------------------------------------------------------

MetaImpl(ShapeView, (TP(shape1), TP(shape2), TP(selected)));

ShapeView::ShapeView(Document *d, Point ext) : View(d, ext)
{
    shape1 = new BoxShape(Rectangle(100,100,100,100)); 
    shape2 = new OvalShape(Rectangle(150,150,100,100));
    shape1->SetContainer(this);
    shape2->SetContainer(this);
}

ShapeView::~ShapeView()
{
    SafeDelete(shape1);
    SafeDelete(shape2);
}

void ShapeView::Draw(Rectangle r)
{
    shape1->DrawAll(r);
    shape2->DrawAll(r);
}

Command *ShapeView::DoLeftButtonDownCommand(Point p, Token t, int cl)
{
    if (shape2->ContainsPoint(p))
        selected= shape2;
    else if (shape1->ContainsPoint(p))
        selected= shape1;
    if (selected) {
        if (t.Flags & eFlgCntlKey)
            return selected->GetStretcher();
        return selected->GetMover();
    }
    return View::DoLeftButtonDownCommand(p, t, cl);
}


istream &ShapeView::ReadFrom(istream &s)
{
    SafeDelete(shape1);
    SafeDelete(shape2);
    s >> shape1 >> shape2;
    shape1->SetContainer(this);
    shape2->SetContainer(this);
    ForceRedraw();
    return s;
}

void ShapeView::DoCreateMenu(Menu *menu)
{
    Menu *submenu = new Menu("patterns", FALSE, 0, 2);

    submenu->AppendItems( 
    		      "White",	   cWHITE,
    		      "Grey25",	   cGREY25,	
    		      "Grey50",    cGREY50,
    		      "Grey75",	   cGREY75,
    		      "Black",	   cBLACK,
    		      "Pattern00", cPAT00,
    		      "Pattern01", cPAT01,
    		      "Pattern02", cPAT02,
    		      "Red",	   cRED,
    		      "Green",	   cGREEN,
    		      "Blue",	   cBLUE,
    		      0);

    View::DoCreateMenu(menu);

    menu->AppendMenu(submenu, cPATTERNMENU);
}

void ShapeView::DoSetupMenu(Menu *menu)
{
    View::DoSetupMenu(menu);

    for (int p= 0; palette[p]; p++)
	menu->EnableItem(cWHITE+p);

    menu->EnableItem(cPATTERNMENU);
}

Command *ShapeView::DoMenuCommand(int cmd)
{
    if (cmd >= cWHITE && cmd <= cWHITE+cMAXINKS)
	return new PatternCommand(selected, cmd-cWHITE);

    return View::DoMenuCommand(cmd);
}


